@@ -15,14 +15,9 @@ function (x, y, scope, flip.y, ceilings, bottleneck.x, bottleneck.y, steps, step
   attr(mp, "cutoff") <- cutoff
 
   bottlenecks <- list()
-  if ("lh"          %in% ceilings) { bottlenecks[['lh']]          <- mp }
-  if ("cols"        %in% ceilings) { bottlenecks[['cols']]        <- mp }
-  if ("qr"          %in% ceilings) { bottlenecks[['qr']]          <- mp }
-  if ("ce_vrs"      %in% ceilings) { bottlenecks[['ce_vrs']]      <- mp }
-  if ("cr_vrs"      %in% ceilings) { bottlenecks[['cr_vrs']]      <- mp }
-  if ("ce_fdh"      %in% ceilings) { bottlenecks[['ce_fdh']]      <- mp }
-  if ("cr_fdh"      %in% ceilings) { bottlenecks[['cr_fdh']]      <- mp }
-  if ("sfa"         %in% ceilings) { bottlenecks[['sfa']]         <- mp }
+  for (ceil in setdiff(ceilings, p_no_bottleneck)) {
+    bottlenecks[[ceil]]          <- mp
+  }
 
   return( list(
     bottlenecks=bottlenecks,
